
# Ntfy_CSV_Reminders
Send a notification every few days as reminder. Inputs are based on a simple csv text file.

# Getting started
* From pypi:
    * As a tool: `uvx Ntfy_CSV_Reminders@latest --help`
    * Via uv: `uv pip install Ntfy_CSV_Reminders`
    * Via pip: `pip install Ntfy_CSV_Reminders`
* From github:
    * Clone this repo then `pip install .`
